@@ -8,54 +8,66 @@ import sys
 from pyramid.httpexceptions import WSGIHTTPException
 from pyramid.tweens import EXCVIEW
 from pyramid.util import DottedNameResolver
+from pyramid.settings import asbool
 
 import rollbar
 
 DEFAULT_WEB_BASE = 'https://rollbar.com'
+BOOLEAN_SETTINGS = [
+    'rollbar.enabled', 'rollbar.allow_logging_basic_config',
+    'rollbar.verify_https'
+]
 
 log = logging.getLogger(__name__)
 
-def handle_error(settings, request):
-    rollbar.report_exc_info(sys.exc_info(), request)
+
+EXCEPTION_BLACKLIST = (WSGIHTTPException,)
+EXCEPTION_WHITELIST = tuple()
+
+
+def handle_error(request, exception, exc_info):
+    if(
+            isinstance(exception, EXCEPTION_BLACKLIST) and
+            not isinstance(exception, EXCEPTION_WHITELIST)
+    ):
+        return
+    rollbar.report_exc_info(exc_info, request)
 
 
 def parse_settings(settings):
     prefix = 'rollbar.'
     out = {}
-    for k, v in settings.iteritems():
+    for k, v in settings.items():
         if k.startswith(prefix):
+            if k in BOOLEAN_SETTINGS:
+                v = asbool(v)
             out[k[len(prefix):]] = v
+
     return out
 
 
 def rollbar_tween_factory(pyramid_handler, registry):
     settings = parse_settings(registry.settings)
 
-    whitelist = ()
-    blacklist = (WSGIHTTPException,)
-
     def rollbar_tween(request):
         # for testing out the integration
         try:
             if (settings.get('allow_test', 'true') == 'true' and
-                request.GET.get('pyramid_rollbar_test') == 'true'):
+                    request.GET.get('pyramid_rollbar_test') == 'true'):
                 try:
                     raise Exception("pyramid_rollbar test exception")
-                except:
-                    handle_error(settings, request)
+                except Exception as exc:
+                    handle_error(request, exc, sys.exc_info())
         except:
             log.exception("Error in pyramid_rollbar_test block")
 
         try:
             response = pyramid_handler(request)
-        except whitelist:
-            handle_error(settings, request)
-            raise
-        except blacklist:
-            raise
-        except:
-            handle_error(settings, request)
+        except Exception as exc:
+            handle_error(request, exc, sys.exc_info())
             raise
+        if request.exception is not None:
+            handle_error(request, request.exception, request.exc_info)
         return response
 
     return rollbar_tween
@@ -89,9 +101,11 @@ def patch_debugtoolbar(settings):
 
     # patch tbtools.Traceback.render_full
     old_render_full = tbtools.Traceback.render_full
+
     def new_render_full(self, request, *args, **kw):
         html = old_render_full(self, request, *args, **kw)
         return insert_rollbar_console(request, html)
+
     tbtools.Traceback.render_full = new_render_full
 
 
@@ -99,16 +113,17 @@ def includeme(config):
     """
     Pyramid entry point
     """
-    config.add_tween('rollbar.contrib.pyramid.rollbar_tween_factory', under=EXCVIEW)
+    settings = config.registry.settings
+
+    config.add_tween('rollbar.contrib.pyramid.rollbar_tween_factory', over=EXCVIEW)
 
     # run patch_debugtoolbar, unless they disabled it
-    settings = config.registry.settings
-    if settings.get('rollbar.patch_debugtoolbar', 'true') == 'true':
+    if asbool(settings.get('rollbar.patch_debugtoolbar', True)):
         patch_debugtoolbar(settings)
 
     def hook(request, data):
         data['framework'] = 'pyramid'
-        
+
         if request:
             request.environ['rollbar.uuid'] = data['uuid']
 
@@ -124,22 +139,24 @@ def includeme(config):
 
     if kw.get('scrub_fields'):
         kw['scrub_fields'] = set([str.strip(x) for x in kw.get('scrub_fields').split('\n') if x])
-    
+
     if kw.get('exception_level_filters'):
         r = DottedNameResolver()
         exception_level_filters = []
         for line in kw.get('exception_level_filters').split('\n'):
             if line:
                 dotted_path, level = line.split()
-                
+
                 try:
                     cls = r.resolve(dotted_path)
                     exception_level_filters.append((cls, level))
                 except ImportError:
                     log.error('Could not import %r' % dotted_path)
-        
+
         kw['exception_level_filters'] = exception_level_filters
-    
+
+    kw['enabled'] = asbool(kw.get('enabled', True))
+
     rollbar.init(access_token, environment, **kw)
 
 
@@ -159,7 +176,7 @@ class RollbarMiddleware(object):
     def __call__(self, environ, start_resp):
         try:
             return self.app(environ, start_resp)
-        except Exception, e:
+        except Exception:
             from pyramid.request import Request
             handle_error(self.settings, Request(environ))
             raise
